# Wordpress Theme Development Kit

Wisk is a CLI Tool to build all the boilerplate files for a Custom Wordpress Theme.  Just navigate to your themes folder in your terminal and use 'wsk' to generate the files.  There are options for with or without bootstrap, sass, and classic or block templating.  By default, bootstrap, sass, and classic mode are True.  
